//

// Licensed Materials - Property of IBM

// 5724-Q87 

// IBM Tivoli Reporting

//

// (C) Copyright IBM Corp. 2007,2008 All Rights Reserved.

//

// US Government Users Restricted Rights - Use, duplication or

// disclosure restricted by GSA ADP Schedule Contract with

// IBM Corp.



//Javascript functions needed in report wide namespace.  There is

//currently no support in the BIRT Designer Eclipse GUI for specifying

//that a report should use this file.  To use in a report, you

//have to edit the .rptdesign file by hand, and insert the following:

//    <list-property name="includeScripts">

//        <property>tcr_common/scripts/ModifyQuery.js</property>

//    </list-property>

//You can insert it after the <method> ... </method> near the beginning

//of the file.  You CAN refer to the methods in this file from scripts

//with the report.





//-----------------------------------------------------------------------------------------------------

// Modify the current query by adding an additional filter to the end of the original query.

// You can call this in the beforeOpen() method of the data set.

// Arguments:

//   dataset - dataset object of the calling beforeOpen() method

//   filter  - SQL relational expression.

//-----------------------------------------------------------------------------------------------------

function ModifyQueryAppendFilter (dataset,filter)

{

    //Log information

    //dsDebugLogger("Entering ModifyQueryAppendFilter");

    debugLogger = ((""+typeof(debugLogger)) != "undefined" ) ? debugLogger : function(s) {};

    

    try {      

        var qt = dataset.queryText;

      	//Log query before append

      	debugLogger("Query before append: "+qt);

      	//Modify the query

      	dataset.queryText = qt+" AND "+filter;

      	//Log query after append

      	debugLogger("Query after append: " + dataset.queryText);

    } catch (ex) {

         debugLogger("ModifyQueryAppendFilter: "+ex);

    }

}



//-----------------------------------------------------------------------------------------------------

// Generally used for modifying query attributes such as column names and etc.  

// The specified attributes (old attribute and the attribute to be replaced) may be separated by sep.

// You can call this in the beforeOpen() method of the data set.

// Arguments:

//   dataset - dataset object of the calling beforeOpen() method

//   attribute  - attribute in specified query. Example column name, and etc.

//   sep - separator used to split the string.

//-----------------------------------------------------------------------------------------------------

function ModifyQueryAttributes(dataset,attributes,sep) {

  try{

    	var old_query = dataset.queryText;

    	//Log query before attribute change

    	debugLogger("Query before attribute change: "+old_query);

    	var n = attributes.length;

    	debugLogger("Number of attributes to modify: "+n);

    	for(var i=0;i<n;++i){

         	var attrs = attributes[i].split(sep);//Use specified separator to split the string

         	var old_attr = attrs[0];

         	var new_attr = attrs[1];

         	old_query = replaceSubString(old_query,old_attr,new_attr);//Keep replacing

         	//Log attribute change

         	debugLogger("Replacing attribute: "+old_attr+" with attribute: "+new_attr);

    	}

    	//Modify query

    	dataset.queryText = old_query;

    	//Log query after attribute change

    	debugLogger("Query after attributes change: "+ dataset.queryText);   

  }

  catch(ex){

    debugLogger("ModifyQueryAttributes: "+ex);

  }

}



//-----------------------------------------------------------------------------------------------------

// Modifies a query with summarization level.

// You can call this in the beforeOpen() method of the data set.

// Arguments:

//   dataset - dataset object of the calling beforeOpen() method

//   attribute  - attribute in specified query. Example column name, and etc.

//   sep - separator used to split the string.

//   sum_level_code - the summarization level code. Example H, M, and etc.

//-----------------------------------------------------------------------------------------------------

function ModifyQueryWithSummarizationLevel(dataset,attributes,sep,sum_level_code){

  try {

      var shift_pd = " AND SHIFTPERIOD = -1";

      //Modify the attributes. Used to change the tables in query specifically.

      ModifyQueryAttributes(dataset,attributes,sep);

      var ds_query = dataset.queryText;

      //Log query before shift

      debugLogger("Query before shift: "+ds_query);

      //Append with appropriate SHIFTPERIOD

      if(sum_level_code != "H"){//Not hourly

        	dataset.queryText = ds_query+shift_pd;

      }

      //Log query after shift

      debugLogger("After shift query: "+dataset.queryText);    

  }

  catch(ex){

     debugLogger("ModifyQueryWithSummarizationLevel: "+ex);

  }

}









