//

// Licensed Materials - Property of IBM

// 5724-Q87 

// IBM Tivoli Reporting

//

// (C) Copyright IBM Corp. 2007,2008 All Rights Reserved.

//

// US Government Users Restricted Rights - Use, duplication or

// disclosure restricted by GSA ADP Schedule Contract with

// IBM Corp.



//Javascript functions needed in report wide namespace.  There is

//currently no support in the BIRT Designer Eclipse GUI for specifying

//that a report should use this file.  To use in a report, you

//have to edit the .rptdesign file by hand, and insert the following:

//    <list-property name="includeScripts">

//        <property>tcr_common/scripts/ReportUtils.js</property>

//    </list-property>

//You can insert it after the <method> ... </method> near the beginning

//of the file.  You CAN refer to the methods in this file from scripts

//with the report.



//-----------------------------------------------------------------------------------------------------

// Performs generic functions before report is run.

// For now, this function initializes logging for the report.

// You can call this in the initialize() method of the report.

//-----------------------------------------------------------------------------------------------------

function doBeforeReport(){

    //Initialize logger

    reportContext.setPersistentGlobalVariable("logfileName", "BIRT_Logfile.txt");

    setupLogging();

    logInitialize();

    debugLogger("doBeforeReport()");

}



//-----------------------------------------------------------------------------------------------------

// Performs generic functions after report is run.

// For now, this function closes logging for the report.

// You can call this in the afterFactory() method or some other related methods of the report.

//-----------------------------------------------------------------------------------------------------

function doAfterReport(){

    //Close logging

	debugLogger("doAfterReport()");

	closeLogger();

}





//-----------------------------------------------------------------------------------------------------

// Retrieves the summarization level code from specified string.

// Arguments:

//   summarization_level - summarization level.

// This is the character that follows the last occurence of the symbol "_" in a summarization table.

// Example Summ_Table_Q will return Q,Summ_Table_H will return H, and etc.

// You can call this in the beforeOpen() method of the data set in combination with other related 

// summarization methods.

//-----------------------------------------------------------------------------------------------------

function getSummarizationCode(summarization_level){

   var code = "NONE";//No code available

   if(summarization_level != "Default" && (summarization_level !=null && summarization_level !="")){

      try {

         //Ge tsummarization code

         code = summarization_level.substring(0,1);

      }

      catch(ex){

         debugLogger("getSummarizationCode: "+ex);

      }

   }

   return code;

}





//-----------------------------------------------------------------------------------------------------

// Replaces all occurrences of specified string with new string within specified string.

// Arguments:

//   word_str  - the string containing the value to be replaced.

//   old_value - the string to be replaced.

//   new_value - the new string.

// You can call this in the beforeOpen() method of the data set in combination with other methods.

//-----------------------------------------------------------------------------------------------------

function replaceSubString(word_str,old_value,new_value){

  if(word_str == null || word_str == ""){

     return word_str;

  }

  return word_str.replace(old_value,new_value);

}





//-----------------------------------------------------------------------------------------------------

// Formats a table name. This is generally used for Summarization purposes but may be 

// used for other situations. 

// Arguments:

//   table_name - the original table name.

//   append_str - the string to be used in table name format.

// You can call this in the beforeOpen() method of the data set in combination with other methods.

//-----------------------------------------------------------------------------------------------------

function formatChangeTableName(table_name,append_str){

  var n_tbl = null;

  try {

      var pos = table_name.lastIndexOf("\"");

      if(pos >=0){//Table has quotes. Remove last quotes

          n_tbl = table_name.substr(0,pos)+"_"+append_str+"\"";

      }

      else {//No quotes

        n_tbl = table_name+"_"+append_str+"\"";

      }

      //Log the change

      debugLogger("Table new name: "+n_tbl);

  }

  catch(ex){

      debugLogger("formatChangeTableName: "+ex);

  }

  return n_tbl;

}

